@@ -1,4 +1,4 @@
-from sp_api.base import sp_endpoint, fill_query_params, ApiResponse
+from sp_api.base import sp_endpoint, fill_query_params, ApiResponse, deprecated
 from sp_api.base import Client, Marketplaces
 
 
@@ -46,7 +46,7 @@ class Orders(Client):
             key EasyShipShipmentStatuses: [str]
             key NextToken: str
             key AmazonOrderIds: [str]
-
+            key RestrictedResources: [str]
 
         Returns:
             ApiResponse:
@@ -81,6 +81,7 @@ class Orders(Client):
 
         Args:
             order_id: str
+            key RestrictedResources: [str]
             **kwargs:
 
         Returns:
@@ -128,6 +129,7 @@ class Orders(Client):
 
         Args:
             order_id: str
+            key RestrictedResources: [str]
             **kwargs:
 
         Returns:
