@@ -74,7 +74,8 @@ class CredentialProvider:
                      lwa_client_secret,
                      aws_access_key,
                      aws_secret_key,
-                     role_arn
+                     role_arn,
+                     use_instance_profile=None
                      ):
             self.refresh_token = refresh_token
             self.lwa_app_id = lwa_app_id
