@@ -1,8 +1,10 @@
 import time
 
 
-def make_sleep_time(rate_limit):
-    return 1 / float(rate_limit)
+def make_sleep_time(rate_limit, use_rate_limit_header, throttle_by_seconds):
+    if use_rate_limit_header and rate_limit:
+        return 1 / float(rate_limit)
+    return throttle_by_seconds
 
 
 def load_all_pages(throttle_by_seconds: float = 2, next_token_param='NextToken', use_rate_limit_header: bool = False):
@@ -24,7 +26,7 @@ def load_all_pages(throttle_by_seconds: float = 2, next_token_param='NextToken',
             if res.next_token:
                 kwargs.clear()
                 kwargs.update({next_token_param: res.next_token})
-                sleep_time = make_sleep_time(res.rate_limit) if use_rate_limit_header and res.rate_limit else throttle_by_seconds
+                sleep_time = make_sleep_time(res.rate_limit, use_rate_limit_header, throttle_by_seconds)
                 for x in wrapper(*args, **kwargs):
                     yield x
                     if sleep_time > 0:
